config

package
v0.0.0-...-4f7ee9a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package config provides functions to work with tool configuration.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetSchemasPath

func GetSchemasPath() string

GetSchemasPath checks if the directory for schemas exists and returns either its path, or an empty string.

Types

This section is empty.

Jump to