Documentation
¶
Overview ¶
Package config provides functions to work with tool configuration.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetSchemasPath ¶
func GetSchemasPath() string
GetSchemasPath checks if the directory for schemas exists and returns either its path, or an empty string.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.